==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Skapa nät från form...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tessellera form</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation type="unfinished">Create section from mesh and plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Sektionering</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Trimma mesh med ett plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Trimmar en mesh med ett plan</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Skapa</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Rensa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Avbryt</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ingen punkt markerades</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Tråd</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation type="unfinished"> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Kontinuitet</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation type="unfinished">Start</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessellering</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Former</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation type="unfinished">Meshing options</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation type="unfinished">Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation type="unfinished">Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation type="unfinished">Define segments by face colors</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maximal kantlängd:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Finhet:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Väldigt grov</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grov</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Måttlig</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Mycket fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Användardefinierad</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation type="unfinished">Mesh size grading:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Element per kant:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation type="unfinished">Elements per curvature radius:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimera yta</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Andra ordningens element</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation type="unfinished">Quad dominated</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Inställningar</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Ytavvikelse:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. kantlängd:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Markera en form för nät, först.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Inget sådant dokument '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Välj plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Välj plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Välj ett plan för vilken du önskar trimma din mesh.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>NätDel</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Skapa nät från form...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tessellera form</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Skapa urval från nät och plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Sektionering</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>Nät</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Trimma mesh med ett plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Trimmar en mesh med ett plan</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Skapa</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Rensa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Avbryt</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ingen punkt markerades</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Tråd</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation type="unfinished"> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Kontinuitet</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation type="unfinished">Start</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessellering</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Former</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation type="unfinished">Meshing options</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation type="unfinished">Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation type="unfinished">Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation type="unfinished">Define segments by face colors</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maximal kantlängd:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Finhet:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Väldigt grov</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grov</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Måttlig</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Mycket fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Användardefinierad</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation type="unfinished">Mesh size grading:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Element per kant:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation type="unfinished">Elements per curvature radius:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimera yta</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Andra ordningens element</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation type="unfinished">Quad dominated</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Inställningar</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Ytavvikelse:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. kantlängd:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Markera en form för nät, först.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Inget sådant dokument '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Välj plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Välj plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Välj ett plan för vilken du önskar trimma din mesh.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation type="unfinished">Trim by plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation type="unfinished">Select the side you want to keep.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Inre</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Yttre</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation type="unfinished">Split</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>NätDel</translation>
    </message>
  </context>
</TS>
